@@ -36,12 +36,11 @@ from itertools import combinations
 from typing import Generator
 
 from monty.json import MSONable
-from pymatgen.analysis.structure_matcher import StructureMatcher
 from pymatgen.core import Element, PeriodicSite, Species, Structure
 from pymatgen.io.vasp import Chgcar
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
-from pymatgen.analysis.defects.core import Interstitial, Substitution, Vacancy
+from pymatgen.analysis.defects.core import Defect, Interstitial, Substitution, Vacancy
 from pymatgen.analysis.defects.utils import ChargeInsertionAnalyzer, remove_collisions
 
 __author__ = "Jimmy-Xuan Shen"
@@ -67,18 +66,9 @@ class DefectGenerator(MSONable, metaclass=ABCMeta):
         else:
             raise ValueError("This generator does not have symprec and angle_tolerance")
 
-    def _stucture_matcher(self) -> StructureMatcher:
-        """Get the ``StructureMatcher``."""
-        if (
-            hasattr(self, "ltol")
-            and hasattr(self, "stol")
-            and hasattr(self, "angle_tol")
-        ):
-            return StructureMatcher(
-                ltol=self.ltol, stol=self.stol, angle_tol=self.angle_tol
-            )
-        else:
-            raise ValueError("This generator does not have symprec and angle_tolerance")
+    def get_defects(self, *args, **kwargs) -> list[Defect]:
+        """Call the generator and convert the results into a list."""
+        return list(self.generate(*args, **kwargs))
 
 
 class VacancyGenerator(DefectGenerator):
@@ -98,7 +88,7 @@ class VacancyGenerator(DefectGenerator):
         self.symprec = symprec
         self.angle_tolerance = angle_tolerance
 
-    def get_defects(
+    def generate(
         self, structure: Structure, rm_species: list[str | Species] = None, **kwargs
     ) -> Generator[Vacancy, None, None]:
         """Generate a vacancy defects.
@@ -145,7 +135,7 @@ class SubstitutionGenerator(DefectGenerator):
         self.symprec = symprec
         self.angle_tolerance = angle_tolerance
 
-    def get_defects(
+    def generate(
         self, structure: Structure, substitution: dict[str, list[str]], **kwargs
     ) -> Generator[Substitution, None, None]:
         """Generate subsitutional defects.
@@ -190,7 +180,7 @@ class AntiSiteGenerator(DefectGenerator):
         self.symprec = symprec
         self.angle_tolerance = angle_tolerance
 
-    def get_defects(
+    def generate(
         self,
         structure: Structure,
         **kwargs,
@@ -206,7 +196,7 @@ class AntiSiteGenerator(DefectGenerator):
             subs[u].append(v)
             subs[v].append(u)
         logger.debug(f"All anti-site pairings: {subs}")
-        return SubstitutionGenerator.get_defects(self, structure, subs)
+        return SubstitutionGenerator.generate(self, structure, subs)
 
 
 class InterstitialGenerator(DefectGenerator):
@@ -218,7 +208,7 @@ class InterstitialGenerator(DefectGenerator):
         """
         self.min_dist = min_dist
 
-    def get_defects(
+    def generate(
         self, structure: Structure, insertions: dict[str, list[list[float]]], **kwargs
     ) -> Generator[Interstitial, None, None]:
         """Generate interstitials.
@@ -289,7 +279,7 @@ class ChargeInterstitialGenerator(InterstitialGenerator):
         self.max_avg_charge = max_avg_charge
         super().__init__(min_dist=min_dist)
 
-    def get_defects(self, chgcar: Chgcar, insert_species: set[str] | list[str], **kwargs) -> Generator[Interstitial, None, None]:  # type: ignore[override]
+    def generate(self, chgcar: Chgcar, insert_species: set[str] | list[str], **kwargs) -> Generator[Interstitial, None, None]:  # type: ignore[override]
         """Generate interstitials.
 
         Args:
@@ -301,7 +291,7 @@ class ChargeInterstitialGenerator(InterstitialGenerator):
             raise ValueError("Insert species must be unique.")
         cand_sites = [*self._get_candidate_sites(chgcar)]
         for species in insert_species:
-            yield from super().get_defects(chgcar.structure, {species: cand_sites})
+            yield from super().generate(chgcar.structure, {species: cand_sites})
 
     def _get_candidate_sites(self, chgcar: Chgcar):
         cia = ChargeInsertionAnalyzer(
@@ -326,7 +316,7 @@ def _element_str(sp_or_el: Species | Element) -> str:
     elif isinstance(sp_or_el, Element):
         return str(sp_or_el)
     else:
-        raise ValueError(f"{sp_or_el} is not a species or element")
+        raise ValueError(f"{sp_or_el} is not a species or element")  # pragma: no cover
 
 
 def _remove_oxidation_states(structure: Structure) -> Structure:
